{% extends 'base.html' %}

{% block title %}Chef roles{% endblock %}

{% block content %}
<ul class="attempt-columns">
{% for role in roles | sort %}
  <li>
    <a href="{{ url_for('.role', name=role) }}">
      <code>{{ role }}</code>
    </a>
  </li>
{% endfor %}
</ul>
{% endblock %}
