{% extends 'base.html' %}
{% block title %}Chef environments{% endblock %}
{% block content %}
<ul class="attempt-columns">
{% for environment in environments | sort %}
  <li>
    <a href="{{ url_for('.environment', name=environment) }}">
      <code>{{ environment }}</code>
    </a>
  </li>
{% endfor %}
</ul>
{% endblock %}
