"""Default Flask configuration setttings"""

# A default secret key, so that sessions work out of the box
SECRET_KEY = 'default-secret-key'

# The default selected chef environment to display
DEFAULT_CHEF_ENVIRONMENT = '*'

# The Chef API to use
CHEF_URL = None
CHEF_KEY = None
CHEF_CLIENT = None
